import styled from "styled-components";

export type Props = { content?: string, icon?: string, link?: string }
const Button: React.FC<React.ComponentProps<'div'> & Props> = ({ content, icon, link, children, ...props }) => {
    const item = <ButtonStyled {...props} className={link && "link"}>
        {icon && <img src={icon} alt="Button icon"/>}
        {content || children}
    </ButtonStyled>;

    return link ? <a href={link} target="_blank" rel="noreferrer">{item}</a> : item;
}

const ButtonStyled = styled.div`
    gap: ${({ theme }) => theme.gap};
    display: flex;
    align-items: center;

    border-radius: 10px;
    padding: 0.5rem 1rem;
    transition: 0.2s ease-in-out;
    border: 1px solid ${({ theme }) => theme.border};
    cursor: default;

    &.link { cursor: pointer; }
    &:hover {
        background: ${({ theme }) => theme.text};
        color: ${({ theme }) => theme.secondary};

        img {
            filter: invert();
        }
    }

    ${({ theme }) => theme.type === 'dark' && `
        img {
            filter: invert();
        }

        &:hover img {
            filter: none;
        }
    `}

    &:active {
        transform: scale(0.9);
    }

    img {
        max-width: 20px;
        max-height: 20px;
        transition-delay: 0.1s;
    }
`;

export default Button;